'\" te
.\" Copyright (c) 2001, the Institute of Electrical and Electronics Engineers, Inc. and The Open Group. All Rights Reserved.
.\" Copyright (c) 1992, X/Open Company Limited.  All Rights Reserved.
.\" Portions Copyright (c) 2006, Sun Microsystems, Inc. All Rights Reserved.
.\" Sun Microsystems, Inc. gratefully acknowledges The Open Group for permission to reproduce portions of its copyrighted documentation. Original documentation from The Open Group can be obtained online at 
.\" http://www.opengroup.org/bookstore/.
.\" The Institute of Electrical and Electronics Engineers and The Open Group, have given us permission to reprint portions of their documentation. In the following statement, the phrase "this text" refers to portions of the system documentation. Portions of this text are reprinted and reproduced in electronic form in the Sun OS Reference Manual, from IEEE Std 1003.1, 2004 Edition, Standard for Information Technology -- Portable Operating System Interface (POSIX), The Open Group Base Specifications Issue 6, Copyright (C) 2001-2004 by the Institute of Electrical and Electronics Engineers, Inc and The Open Group. In the event of any discrepancy between these versions and the original IEEE and The Open Group Standard, the original IEEE and The Open Group Standard is the referee document. The original Standard can be obtained online at http://www.opengroup.org/unix/online.html.
.\"  This notice shall appear on any product containing this material.
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
.TH atanh 3M "12 Jul 2006" "SunOS 5.11" "Mathematical Library Functions"
.SH NAME
atanh, atanhf, atanhl \- inverse hyperbolic tangent functions
.SH SYNOPSIS
.LP
.nf
c99 [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
#include <math.h>

\fBdouble\fR \fBatanh\fR(\fBdouble\fR \fIx\fR);
.fi

.LP
.nf
\fBfloat\fR \fBatanhf\fR(\fBfloat\fR \fIx\fR);
.fi

.LP
.nf
\fBlong double\fR \fBatanhl\fR(\fBlong double\fR \fIx\fR);
.fi

.SH DESCRIPTION
.sp
.LP
These functions compute the inverse hyperbolic tangent of their argument
\fIx\fR.
.SH RETURN VALUES
.sp
.LP
Upon successful completion, these functions return the inverse hyperbolic
tangent of their argument.
.sp
.LP
If \fIx\fR is \(+-1, a pole error occurs and \fBatanh()\fR, \fBatanhf()\fR, and
\fBatanhl()\fR return the value of the macro \fBHUGE_VAL\fR, \fBHUGE_VALF\fR,
and \fBHUGE_VALL\fR, respectively, with the same sign as the correct value of
the function.
.sp
.LP
For finite |\fIx\fR| > 1, a domain error occurs and a NaN is returned.
.sp
.LP
If \fIx\fR is NaN, NaN is returned.
.sp
.LP
If \fIx\fR is +0, \fIx\fR is returned.
.sp
.LP
If \fIx\fR is +Inf, a domain error occurs and a NaN is returned.
.sp
.LP
For exceptional cases, \fBmatherr\fR(3M) tabulates the values to be returned by
\fBatanh()\fR as specified by SVID3 and XPG3.
.SH ERRORS
.sp
.LP
These functions will fail if:
.sp
.ne 2
.mk
.na
\fBDomain Error\fR
.ad
.RS 16n
.rt  
The \fIx\fR argument is finite and not in the range [-1,1], or is \(+-Inf.
.sp
If the integer expression (\fBmath_errhandling\fR & \fBMATH_ERREXCEPT\fR) is
non-zero, the invalid floating-point exception is raised.
.sp
The \fBatanh()\fR function sets \fBerrno\fR to \fBEDOM\fR if the absolute value
of \fIx\fR is greater than 1.0.
.RE

.sp
.ne 2
.mk
.na
\fBPole Error\fR
.ad
.RS 16n
.rt  
The \fIx\fR argument is \(+-1.
.sp
If the integer expression (math_errhandling & MATH_ERREXCEPT) is non-zero, then
the divide-by-zero floating-point exception is raised.
.sp
The \fBatanh()\fR function sets \fBerrno\fR to \fBERANGE\fR if the absolute
value of \fIx\fR is equal to 1.0.
.RE

.SH USAGE
.sp
.LP
An application wanting to check for exceptions should call
\fBfeclearexcept\fR(\fBFE_ALL_EXCEPT\fR) before calling these functions. On
return, if \fBfetestexcept\fR(\fBFE_INVALID\fR | \fBFE_DIVBYZERO\fR |
\fBFE_OVERFLOW\fR | \fBFE_UNDERFLOW\fR) is non-zero, an exception has been
raised. An application should either examine the return value or check the
floating point exception flags to detect exceptions.
.sp
.LP
An application can also set \fBerrno\fR to 0 before calling \fBatanh()\fR. On
return, if \fBerrno\fR is non-zero, an error has occurred. The \fBatanhf()\fR
and \fBatanhl()\fR functions do not set \fBerrno\fR.
.SH ATTRIBUTES
.sp
.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp

.sp
.TS
tab() box;
cw(2.75i) |cw(2.75i) 
lw(2.75i) |lw(2.75i) 
.
ATTRIBUTE TYPEATTRIBUTE VALUE
_
Interface StabilityStandard
_
MT-LevelMT-Safe
.TE

.SH SEE ALSO
.sp
.LP
\fBfeclearexcept\fR(3M), \fBfetestexcept\fR(3M), \fBmath.h\fR(3HEAD),
\fBmatherr\fR(3M), \fBtanh\fR(3M), \fBattributes\fR(5), \fBstandards\fR(5)
